@@ -17,7 +17,7 @@ class TestTimestreamLoader_UnitTests:
     @pytest.mark.unit
     def test_load(self):
         mock_session = self.get_mock_session()
-        loader = TimestreamLoader('test', 'test', mock_session)
+        loader = TimestreamLoader('test.db', 'test.table', mock_session)
         mock_session.assert_expectations()
 
         result = loader.load(
@@ -37,6 +37,8 @@ class TestTimestreamLoader_UnitTests:
         assert type(result['rejected_records']) == list
         assert len(result['rejected_records']) == 0
         assert result['error'] == None
+        assert loader.database_name == 'test.db'
+        assert loader.table_name == 'test.table'
 
     @pytest.mark.unit
     def test_load_preview(self):
@@ -226,6 +228,7 @@ class TestTimestreamLoader_UnitTests:
             'Dimensions': []
         }]
         expected_capture_time = '1609459200000'
+        expected_source = 'test'
 
         # Set up mocks
         mock_client = MockApi()
@@ -248,7 +251,9 @@ class TestTimestreamLoader_UnitTests:
         accepted_records, rejected_records = loader._TimestreamLoader__write_insert_records(
             common_dimensions=TimestreamDimensions(),
             records=[expected_valid_record, expected_invalid_record],
-            capture_time=datetime(2021, 1, 1, 0, 0, 0, 0, tzinfo=pytz.UTC)
+            source=expected_source,
+            capture_time=datetime(2021, 1, 1, 0, 0, 0, 0, tzinfo=pytz.UTC),
+            is_multi=False
         )
         assert len(accepted_records) == 1
         assert accepted_records[0] == expected_valid_record
@@ -284,6 +289,7 @@ class TestTimestreamLoader_UnitTests:
             'MeasureValue': '0.0',
             'Dimensions': []
         }]
+        expected_source = 'test'
 
         # Set up mocks
         mock_client = MockApi()
@@ -309,7 +315,8 @@ class TestTimestreamLoader_UnitTests:
         )
         accepted_records, rejected_records = loader._TimestreamLoader__write_upsert_records(
             common_dimensions=TimestreamDimensions(),
-            records=[expected_valid_record, expected_invalid_record]
+            records=[expected_valid_record, expected_invalid_record],
+            source=expected_source
         )
         assert len(accepted_records) == 1
         assert accepted_records[0] == expected_valid_record
