@@ -67,7 +67,8 @@ class TimestreamLoader(TimestreamReader):
         upsert: bool = False,
         ignore_parse_error: bool = True,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
+        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
+        is_multi: bool = None
 
     ) -> dict:
         '''
@@ -82,7 +83,8 @@ class TimestreamLoader(TimestreamReader):
             ignore_parse_error,
             False,
             max_batch_size,
-            min_common_dimensions
+            min_common_dimensions,
+            is_multi
         ).to_dict()
 
     def load_preview(
@@ -93,7 +95,8 @@ class TimestreamLoader(TimestreamReader):
         upsert: bool = False,
         ignore_parse_error: bool = True,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
+        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
+        is_multi: bool = None
     ) -> dict:
         '''
         Performs a dry run of a Timestream load, including validating the input values and parsing data
@@ -108,7 +111,8 @@ class TimestreamLoader(TimestreamReader):
             ignore_parse_error,
             True,
             max_batch_size,
-            min_common_dimensions
+            min_common_dimensions,
+            is_multi
         ).to_dict()
 
     def __load(
@@ -120,7 +124,8 @@ class TimestreamLoader(TimestreamReader):
         ignore_parse_error: bool = True,
         preview: bool = False,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
+        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
+        is_multi: bool = None
     ) -> TimestreamLoadResult:
         self._logger.info(f'Loading data with {len(data)} elements')
 
@@ -146,9 +151,9 @@ class TimestreamLoader(TimestreamReader):
             if source:
                 dimensions.add_dimension('source', source, overwrite=True)
             if b.records and upsert:
-                accepted_records, rejected_records = self.__write_upsert_records(dimensions, b.records)
+                accepted_records, rejected_records = self.__write_upsert_records(dimensions, b.records, source, is_multi)
             elif b.records:
-                accepted_records, rejected_records = self.__write_insert_records(dimensions, b.records, capture_time)
+                accepted_records, rejected_records = self.__write_insert_records(dimensions, b.records, source, capture_time, is_multi)
 
             if accepted_records:
                 result.add_accepted_records(accepted_records)
@@ -161,22 +166,29 @@ class TimestreamLoader(TimestreamReader):
         self,
         common_dimensions: TimestreamDimensions,
         records: List[TimestreamRecord],
-        capture_time: datetime
+        source: str,
+        capture_time: datetime,
+        is_multi: bool
     ) -> tuple:
         self._logger.info(f'Writing insert records with {len(records)} records')
         assert capture_time, 'A capture time needs to be provided'
         capture_time_ms = self._dt_to_ms(capture_time)
         accepted_records, rejected_records = records, []
         try:
+            common_att = {
+                    'Dimensions': common_dimensions.loadable(),
+                    'MeasureValueType': 'DOUBLE',
+                    'Version': self._current_time_ms,
+                    'Time': str(capture_time_ms),
+                    'Version': 1
+                }
+            if is_multi:
+                common_att['MeasureName'] = source
+                common_att['MeasureValueType'] = 'MULTI'
             _ = self._timestream_write_client.write_records(
                 DatabaseName=self.__database_name,
                 TableName=self.__table_name,
-                CommonAttributes={
-                    'Dimensions': common_dimensions.loadable(),
-                    'MeasureValueType': 'DOUBLE',
-                    'Time': str(capture_time_ms),
-                    'Version': 1
-                },
+                CommonAttributes=common_att,
                 Records=[
                     r.loadable(omit_dimensions=common_dimensions)
                     for r in records
@@ -190,19 +202,26 @@ class TimestreamLoader(TimestreamReader):
     def __write_upsert_records(
         self,
         common_dimensions: TimestreamDimensions,
-        records: List[TimestreamRecord]
+        records: List[TimestreamRecord],
+        source: str,
+        is_multi: bool = None
     ) -> tuple:
         self._logger.info(f'Writing upsert records with {len(records)} records')
         accepted_records, rejected_records = records, []
         try:
-            _ = self._timestream_write_client.write_records(
-                DatabaseName=self.__database_name,
-                TableName=self.__table_name,
-                CommonAttributes={
+            common_att = {
                     'Dimensions': common_dimensions.loadable(),
                     'MeasureValueType': 'DOUBLE',
                     'Version': self._current_time_ms
-                },
+                }
+            if is_multi:
+                common_att['MeasureName'] = source
+                common_att['MeasureValueType'] = 'MULTI'
+                    
+            _ = self._timestream_write_client.write_records(
+                DatabaseName=self.__database_name,
+                TableName=self.__table_name,
+                CommonAttributes=common_att,
                 Records=[
                     r.loadable(omit_dimensions=common_dimensions)
                     for r in records
